@@ -1,9 +1,7 @@
-import os
-import glob
-import pytest
-import numpy as np
 import discretisedfield as df
 import micromagneticmodel as mm
+import numpy as np
+import pytest
 
 
 class TestThreads:
